@@ -3,14 +3,15 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package Syntax::Operator::Eqr 0.08;
+package Syntax::Operator::Eqr 0.09;
 
 use v5.14;
 use warnings;
 
 use Carp;
 
-use meta;
+use meta 0.003_002;
+no warnings 'meta::experimental';
 
 # Load the XS code
 require Syntax::Operator::Equ;
