@@ -3,14 +3,15 @@
 #
 #  (C) Paul Evans, 2021-2023 -- leonerd@leonerd.org.uk
 
-package Syntax::Operator::Equ 0.08;
+package Syntax::Operator::Equ 0.09;
 
 use v5.14;
 use warnings;
 
 use Carp;
 
-use meta;
+use meta 0.003_002;
+no warnings 'meta::experimental';
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, our $VERSION );
